# Contributing

If you already have VS Code and Docker installed, you can click the `Remote - Containers` badge located at teh top of the README file
or [here](https://vscode.dev/redirect?url=vscode://ms-vscode-remote.remote-containers/cloneInVolume?url=https://github.com/microsoft/vscode-remote-try-java)
to get started. Clicking these links will cause VS Code to automatically install the Remote - Containers extension if needed,
clone the source code into a container volume, and spin up a dev container for use.

1. Spin up a dev container
2. Create your feature branch (`git checkout -b feature/fooBar`)
3. Commit your changes (`git commit -am 'Add some fooBar'`)
4. Push to the branch (`git push origin feature/fooBar`)
5. Create a new Pull Request
